@@ -34,11 +34,10 @@ DecorationBridge *findBridge(const QVariantList &args)
 Decoration::Private::Private(Decoration *deco, const QVariantList &args)
     : sectionUnderMouse(Qt::NoSection)
     , bridge(findBridge(args))
-    , client(QSharedPointer<DecoratedClient>(new DecoratedClient(deco, bridge)))
+    , client(std::shared_ptr<DecoratedClient>(new DecoratedClient(deco, bridge)))
     , opaque(false)
     , q(deco)
 {
-    Q_UNUSED(args)
 }
 
 void Decoration::Private::setSectionUnderMouse(Qt::WindowFrameSection section)
@@ -140,14 +139,9 @@ Decoration::Decoration(QObject *parent, const QVariantList &args)
 
 Decoration::~Decoration() = default;
 
-void Decoration::init()
+DecoratedClient *Decoration::client() const
 {
-    Q_ASSERT(!d->settings.isNull());
-}
-
-QWeakPointer<DecoratedClient> Decoration::client() const
-{
-    return d->client.toWeakRef();
+    return d->client.get();
 }
 
 #define DELEGATE(name)                                                                                                                                         \
@@ -226,7 +220,7 @@ DELEGATE(setBorders, borders, const QMargins &, )
 DELEGATE(setResizeOnlyBorders, resizeOnlyBorders, const QMargins &, )
 DELEGATE(setTitleBar, titleBar, const QRect &, )
 DELEGATE(setOpaque, opaque, bool, d->opaque)
-DELEGATE(setShadow, shadow, const QSharedPointer<DecorationShadow> &, d->shadow)
+DELEGATE(setShadow, shadow, const std::shared_ptr<DecorationShadow> &, d->shadow)
 
 #undef DELEGATE
 
@@ -241,7 +235,7 @@ DELEGATE(borders, QMargins)
 DELEGATE(resizeOnlyBorders, QMargins)
 DELEGATE(titleBar, QRect)
 DELEGATE(sectionUnderMouse, Qt::WindowFrameSection)
-DELEGATE(shadow, QSharedPointer<DecorationShadow>)
+DELEGATE(shadow, std::shared_ptr<DecorationShadow>)
 
 #undef DELEGATE
 
@@ -402,14 +396,16 @@ void Decoration::update()
     update(QRect());
 }
 
-void Decoration::setSettings(const QSharedPointer<DecorationSettings> &settings)
+void Decoration::setSettings(const std::shared_ptr<DecorationSettings> &settings)
 {
     d->settings = settings;
 }
 
-QSharedPointer<DecorationSettings> Decoration::settings() const
+std::shared_ptr<DecorationSettings> Decoration::settings() const
 {
     return d->settings;
 }
 
 } // namespace
+
+#include "moc_decoration.cpp"
