@@ -1,30 +1,14 @@
 /*
- * Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+ * SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef KDECORATION2_DECORATIONBUTTON_H
-#define KDECORATION2_DECORATIONBUTTON_H
+#pragma once
 
-#include <kdecoration2/kdecoration2_export.h>
 #include "decorationdefines.h"
+#include <kdecoration2/kdecoration2_export.h>
 
 #include <QObject>
-#include <QPointer>
 #include <QRect>
 
 class QHoverEvent;
@@ -34,7 +18,6 @@ class QWheelEvent;
 
 namespace KDecoration2
 {
-
 class DecorationButtonPrivate;
 class Decoration;
 #ifndef K_DOXYGEN
@@ -132,7 +115,7 @@ public:
      **/
     virtual void paint(QPainter *painter, const QRect &repaintArea) = 0;
 
-    QPointer<Decoration> decoration() const;
+    Decoration *decoration() const;
 
     bool event(QEvent *event) override;
 
@@ -170,12 +153,12 @@ Q_SIGNALS:
     void enabledChanged(bool);
     void checkableChanged(bool);
     void checkedChanged(bool);
-    void geometryChanged(const QRectF&);
+    void geometryChanged(const QRectF &);
     void acceptedButtonsChanged(Qt::MouseButtons);
     void visibilityChanged(bool);
 
 protected:
-    explicit DecorationButton(DecorationButtonType type, const QPointer<Decoration> &decoration, QObject *parent = nullptr);
+    explicit DecorationButton(DecorationButtonType type, Decoration *decoration, QObject *parent = nullptr);
 
     virtual void hoverEnterEvent(QHoverEvent *event);
     virtual void hoverLeaveEvent(QHoverEvent *event);
@@ -187,10 +170,8 @@ protected:
 
 private:
     class Private;
-    QScopedPointer<Private> d;
+    std::unique_ptr<Private> d;
 };
 
 } // namespace
 Q_DECLARE_METATYPE(KDecoration2::DecorationButtonType)
-
-#endif
